@@ -32,8 +32,9 @@ class MessagesQuerySet(AuditQuerySet):
         return super().create(**kwargs)
 
     def update(self, **kwargs):
-        setAttr(kwargs, 'checksum', hashlib.md5(kwargs.get('message').encode()).hexdigest())
-        setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
+        if kwargs.get('message') is not None:
+            setAttr(kwargs, 'checksum', hashlib.md5(kwargs.get('message').encode()).hexdigest())
+            setAttr(kwargs, 'message', f'<pre>{kwargs.get("message")}</pre>')
         return super().update(**kwargs)
 
     def delete(self):
